/**
 * @file
 * Defines the Editing plugin.
 */

/**
 * @module ckenbsp/CkenbspEditing
 */

import {Plugin} from 'ckeditor5/src/core';

/**
 * The editing feature.
 *
 * @extends module:core/plugin~Plugin
 */
export default class CkenbspEditing extends Plugin {
  /**
   * @inheritDoc
   */
  init() {
    const editor = this.editor;
    const textFormatSettings = editor.config.get('ckenbsp')
    console.log()
    if (textFormatSettings['div']) {
      this._fixDiv();
    }
    if (textFormatSettings['p']) {
      this._fixP();
    }
  }

  _fixDiv() {
    const {conversion} = this.editor;

    conversion.for('downcast').elementToElement({
      model: 'htmlDivParagraph',
      converterPriority: 'high',
      view: (modelElement, { writer }) => {
        let htmlAttrs = {
          id: modelElement.getAttribute('id') || null,
          class: modelElement.getAttribute('class') || null,
          style: modelElement.getAttribute('style') || null,
        }

        const elm = writer.createContainerElement('div', htmlAttrs );
        const text = writer.createText('');
        writer.insert(writer.createPositionAt(elm, 0), [text]);
        return elm
      }
    });
  }

  _fixP() {
    const {conversion} = this.editor;

    conversion.for('downcast').elementToElement({
      model: 'paragraph',
      converterPriority: 'high',
      view: (modelElement, { writer }) => {
        let htmlAttrs = {
          class: modelElement.getAttribute('class') || null,
          style: modelElement.getAttribute('style') || null,
        }

        const elm = writer.createContainerElement('p', htmlAttrs );
        const text = writer.createText('');
        writer.insert(writer.createPositionAt(elm, 0), [text]);
        return elm
      }
    });
  }

}
